netapp_ontap.models.fpolicy_event_filters API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_event_filters`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyEventFiltersSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyEventFilters object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `close_with_modification: bool GET POST PATCH`

    Filter the client request for close with modification.

  `close_with_read: bool GET POST PATCH`

    Filter the client request for close with read.

  `close_without_modification: bool GET POST PATCH`

    Filter the client request for close without modification.

  `exclude_directory: bool GET POST PATCH`

    Filter the client requests for directory operations. When this filter is specified directory operations are not monitored.

  `first_read: bool GET POST PATCH`

    Filter the client requests for the first-read.

  `first_write: bool GET POST PATCH`

    Filter the client requests for the first-write.

  `monitor_ads: bool GET POST PATCH`

    Filter the client request for alternate data stream.

  `offline_bit: bool GET POST PATCH`

    Filter the client request for offline bit set. FPolicy server receives notification only when offline files are accessed.

  `open_with_delete_intent: bool GET POST PATCH`

    Filter the client request for open with delete intent.

  `open_with_write_intent: bool GET POST PATCH`

    Filter the client request for open with write intent.

  `setattr_with_access_time_change: bool GET POST PATCH`

    Filter the client setattr requests for changing the access time of a file or directory.

  `setattr_with_allocation_size_change: bool GET POST PATCH`

    Filter the client setattr requests for changing the allocation size of a file.

  `setattr_with_creation_time_change: bool GET POST PATCH`

    Filter the client setattr requests for changing the creation time of a file or directory.

  `setattr_with_dacl_change: bool GET POST PATCH`

    Filter the client setattr requests for changing dacl on a file or directory.

  `setattr_with_group_change: bool GET POST PATCH`

    Filter the client setattr requests for changing group of a file or directory.

  `setattr_with_mode_change: bool GET POST PATCH`

    Filter the client setattr requests for changing the mode bits on a file or directory.

  `setattr_with_modify_time_change: bool GET POST PATCH`

    Filter the client setattr requests for changing the modification time of a file or directory.

  `setattr_with_owner_change: bool GET POST PATCH`

    Filter the client setattr requests for changing owner of a file or directory.

  `setattr_with_sacl_change: bool GET POST PATCH`

    Filter the client setattr requests for changing sacl on a file or directory.

  `setattr_with_size_change: bool GET POST PATCH`

    Filter the client setattr requests for changing the size of a file.

  `write_with_size_change: bool GET POST PATCH`

    Filter the client request for write with size change.